#
# spec file for package jdom2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jdom2
Version:        2.0.6.1
Release:        3.2
Summary:        Java manipulation of XML
License:        Saxpath
Group:          Development/Libraries/Java
URL:            http://www.jdom.org/
Source0:        jdom-%{version}.tar.xz
Patch0:         0001-Adapt-build.patch
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch

%description
JDOM is a Java-oriented object model which models XML documents.
It provides a Java-centric means of generating and manipulating
XML documents. While JDOM inter-operates well with existing
standards such as the Simple API for XML (SAX) and the Document
Object Model (DOM), it is not an abstraction layer or
enhancement to those APIs. Rather, it provides a means of
reading and writing XML data.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n jdom-%{version}

%patch -P 0 -p1

sed -i 's/\r//' LICENSE.txt

# Unable to run coverage: use log4j12 but switch to log4j 2.x
sed -i.coverage "s|coverage, jars|jars|" build.xml

# XPath functionality is not needed
rm -rf core/src/java/org/jdom2/xpath/
sed -i '/import org.jdom2.xpath.XPathFactory/d' core/src/java/org/jdom2/JDOMConstants.java

%build
mkdir -p lib
%{ant} -Dversion=%{version} -Dcompile.target=8 -Dcompile.source=8 -Dj2se.apidoc=%{_javadocdir}/java maven

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 build/package/jdom-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} build/maven/core/%{name}-%{version}.pom %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr build/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc CHANGES.txt COMMITTERS.txt README.md TODO.txt
%license LICENSE.txt

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Aug 23 2023 Fridrich Strba <fstrba@suse.com>
- Drop unused *-junit and *-contrib artifacts
- Reduce drastically dependencies
- Modified patch:
  * 0001-Adapt-build.patch
    + drop junit and contrib jars
* Tue Jan 18 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to 2.0.6.1
  * Upstream release to fix CVE-2021-33813
- Removed patch:
  * jdom2-CVE-2021-33813.patch
    + integrated upstream
- Modified patch:
  * 0001-Adapt-build.patch
    + rebase to changed context
* Thu Jun 17 2021 Pedro Monreal <pmonreal@suse.com>
- Security fix: [bsc#1187446, CVE-2021-33813]
  * XXE issue in SAXBuilder can cause a denial of service via
    a crafted HTTP request
- Add jdom2-CVE-2021-33813.patch
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Remove unnecessary dependency on log4j
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Sat Feb  9 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jdom2 version 2.0.6
